@@ -1,26 +1,8 @@
-/*
- * This file is part of GtkSourceView
- *
- * Copyright (C) 2023 - Sébastien Wilmet <swilmet@gnome.org>
- *
- * GtkSourceView is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * GtkSourceView is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+/* SPDX-FileCopyrightText: 2023-2024 - Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
+#include "config.h"
 #include "gtksourcestyleschemeparser.h"
 #include <glib/gi18n-lib.h>
 #include "gtksourcestyle.h"
@@ -325,6 +307,14 @@ parse_start_element_style_scheme (ParserData   *parser_data,
 	{
 		parser_data->basic_infos->kind = GTK_SOURCE_STYLE_SCHEME_KIND_DARK;
 	}
+	else if (g_strcmp0 (kind, "light-only") == 0)
+	{
+		parser_data->basic_infos->kind = GTK_SOURCE_STYLE_SCHEME_KIND_LIGHT_ONLY;
+	}
+	else if (g_strcmp0 (kind, "dark-only") == 0)
+	{
+		parser_data->basic_infos->kind = GTK_SOURCE_STYLE_SCHEME_KIND_DARK_ONLY;
+	}
 	else
 	{
 		g_set_error (error,
